test: rename testfixtures and fixtures to testdata

Currently, the fixtures are showing errors if gopls is enabled, which
clutters the problems view. The go command ignores directories named
testdata, so rename the test directories to "testdata".

Change-Id: I4218fc044e60ab022abae88e75b9f51d3cdc031d
Reviewed-on: https://go-review.googlesource.com/c/vscode-go/+/264324
Run-TryBot: Rebecca Stambler <rstambler@golang.org>
Reviewed-by: Hyang-Ah Hana Kim <hyangah@gmail.com>
Trust: Hyang-Ah Hana Kim <hyangah@gmail.com>
Trust: Rebecca Stambler <rstambler@golang.org>
diff --git a/test/gopls/extension.test.ts b/test/gopls/extension.test.ts
index 25d82bf..4df045f 100644
--- a/test/gopls/extension.test.ts
+++ b/test/gopls/extension.test.ts
@@ -44,7 +44,7 @@
 	// https://github.com/microsoft/vscode/blob/890f62dfd9f3e70198931f788c5c332b3e8b7ad7/src/vs/workbench/services/workspaces/browser/abstractWorkspaceEditingService.ts#L281
 	//
 	// So, when we start the gopls tests, we start the test extension host with a
-	// dummy workspace, ${projectDir}/test/gopls/testfixtures/src/workspace
+	// dummy workspace, ${projectDir}/test/gopls/testdata/src/workspace
 	// (see test/runTest.ts and launch.json).
 	// Then copy necessary files to the workspace using Env.reset() from the
 	// fixturesRoot directory.
@@ -59,8 +59,8 @@
 		if (!projectDir) {
 			assert.fail('project directory cannot be determined');
 		}
-		this.workspaceDir = path.resolve(projectDir, 'test/gopls/testfixtures/src/workspace');
-		this.fixturesRoot = path.resolve(projectDir, 'test/fixtures');
+		this.workspaceDir = path.resolve(projectDir, 'test/gopls/testdata/src/workspace');
+		this.fixturesRoot = path.resolve(projectDir, 'test/testdata');
 		this.extension = vscode.extensions.getExtension(extensionId);
 		this.fakeOutputChannel = new FakeOutputChannel();
 
diff --git a/test/gopls/testfixtures/src/workspace/.gitignore b/test/gopls/testdata/src/workspace/.gitignore
similarity index 100%
rename from test/gopls/testfixtures/src/workspace/.gitignore
rename to test/gopls/testdata/src/workspace/.gitignore
diff --git a/test/gopls/testfixtures/src/workspace/.vscode/settings.json b/test/gopls/testdata/src/workspace/.vscode/settings.json
similarity index 100%
rename from test/gopls/testfixtures/src/workspace/.vscode/settings.json
rename to test/gopls/testdata/src/workspace/.vscode/settings.json
diff --git a/test/integration/codelens.test.ts b/test/integration/codelens.test.ts
index f28d81d..b5a941b 100644
--- a/test/integration/codelens.test.ts
+++ b/test/integration/codelens.test.ts
@@ -41,7 +41,7 @@
 		// Set up the test fixtures.
 		repoPath = path.join(gopath, 'src', 'test');
 		fixturePath = path.join(repoPath, 'testfixture');
-		fixtureSourcePath = path.join(__dirname, '..', '..', '..', 'test', 'fixtures', 'codelens');
+		fixtureSourcePath = path.join(__dirname, '..', '..', '..', 'test', 'testdata', 'codelens');
 
 		fs.removeSync(repoPath);
 		fs.copySync(fixtureSourcePath, fixturePath, {
diff --git a/test/integration/coverage.test.ts b/test/integration/coverage.test.ts
index fe38424..e0415d9 100644
--- a/test/integration/coverage.test.ts
+++ b/test/integration/coverage.test.ts
@@ -28,7 +28,7 @@
 		await updateGoVarsFromConfig();
 
 		// Set up the test fixtures.
-		fixtureSourcePath = path.join(__dirname, '..', '..', '..', 'test', 'fixtures', 'coverage');
+		fixtureSourcePath = path.join(__dirname, '..', '..', '..', 'test', 'testdata', 'coverage');
 		coverFilePath = path.join(fixtureSourcePath, 'cover.out');
 		return;
 	});
diff --git a/test/integration/extension.test.ts b/test/integration/extension.test.ts
index e7e2191..b7ca763 100644
--- a/test/integration/extension.test.ts
+++ b/test/integration/extension.test.ts
@@ -68,7 +68,7 @@
 
 		repoPath = path.join(gopath, 'src', 'test');
 		fixturePath = path.join(repoPath, 'testfixture');
-		fixtureSourcePath = path.join(__dirname, '..', '..', '..', 'test', 'fixtures');
+		fixtureSourcePath = path.join(__dirname, '..', '..', '..', 'test', 'testdata');
 		generateTestsSourcePath = path.join(repoPath, 'generatetests');
 		generateFunctionTestSourcePath = path.join(repoPath, 'generatefunctiontest');
 		generatePackageTestSourcePath = path.join(repoPath, 'generatePackagetest');
@@ -1245,8 +1245,7 @@
 				assert.equal(
 					expected.length,
 					labels.length,
-					`expected number of completions: ${expected.length} Actual: ${labels.length} at position(${
-					position.line + 1
+					`expected number of completions: ${expected.length} Actual: ${labels.length} at position(${position.line + 1
 					},${position.character + 1}) ${labels}`
 				);
 				expected.forEach((entry, index) => {
diff --git a/test/integration/goDebug.test.ts b/test/integration/goDebug.test.ts
index 35f5f31..0dc9e61 100644
--- a/test/integration/goDebug.test.ts
+++ b/test/integration/goDebug.test.ts
@@ -3,8 +3,8 @@
 import * as path from 'path';
 import { stringify } from 'querystring';
 import * as sinon from 'sinon';
-import {DebugClient} from 'vscode-debugadapter-testsupport';
-import {DebugProtocol} from 'vscode-debugprotocol';
+import { DebugClient } from 'vscode-debugadapter-testsupport';
+import { DebugProtocol } from 'vscode-debugprotocol';
 import {
 	Delve,
 	escapeGoModPath,
@@ -281,11 +281,11 @@
 	const DEBUG_ADAPTER = path.join('.', 'out', 'src', 'debugAdapter', 'goDebug.js');
 
 	const PROJECT_ROOT = path.normalize(path.join(__dirname, '..', '..', '..'));
-	const DATA_ROOT = path.join(PROJECT_ROOT, 'test', 'fixtures');
+	const DATA_ROOT = path.join(PROJECT_ROOT, 'test', 'testdata');
 
 	let dc: DebugClient;
 
-	setup( () => {
+	setup(() => {
 		dc = new DebugClient('node', path.join(PROJECT_ROOT, DEBUG_ADAPTER), 'go');
 
 		// Launching delve may take longer than the default timeout of 5000.
@@ -295,7 +295,7 @@
 		return dc.start();
 	});
 
-	teardown( () =>  dc.stop() );
+	teardown(() => dc.stop());
 
 	/**
 	 * Helper function to assert that a variable has a particular value.
@@ -311,9 +311,9 @@
 	async function assertVariableValue(name: string, val: string): Promise<void> {
 		const threadsResponse = await dc.threadsRequest();
 		assert(threadsResponse.success);
-		const stackTraceResponse = await dc.stackTraceRequest({threadId: threadsResponse.body.threads[0].id});
+		const stackTraceResponse = await dc.stackTraceRequest({ threadId: threadsResponse.body.threads[0].id });
 		assert(stackTraceResponse.success);
-		const scopesResponse = await dc.scopesRequest({frameId: stackTraceResponse.body.stackFrames[0].id});
+		const scopesResponse = await dc.scopesRequest({ frameId: stackTraceResponse.body.stackFrames[0].id });
 		assert(scopesResponse.success);
 		const variablesResponse = await dc.variablesRequest({
 			variablesReference: scopesResponse.body.scopes[0].variablesReference
@@ -476,8 +476,8 @@
 	// The file paths returned from delve use '/' not the native path
 	// separator, so we can replace any instances of '\' with '/', which
 	// allows the hitBreakpoint check to match.
-	const getBreakpointLocation =  (FILE: string, LINE: number) => {
-		return {path: FILE.replace(/\\/g, '/'), line: LINE };
+	const getBreakpointLocation = (FILE: string, LINE: number) => {
+		return { path: FILE.replace(/\\/g, '/'), line: LINE };
 	};
 
 	suite('setBreakpoints', () => {
@@ -498,7 +498,7 @@
 			};
 			const debugConfig = debugConfigProvider.resolveDebugConfiguration(undefined, config);
 
-			return dc.hitBreakpoint(debugConfig, getBreakpointLocation(FILE, BREAKPOINT_LINE) );
+			return dc.hitBreakpoint(debugConfig, getBreakpointLocation(FILE, BREAKPOINT_LINE));
 		});
 
 		test('should stop on a breakpoint in test file', () => {
@@ -517,7 +517,7 @@
 			};
 			const debugConfig = debugConfigProvider.resolveDebugConfiguration(undefined, config);
 
-			return dc.hitBreakpoint(debugConfig, getBreakpointLocation(FILE, BREAKPOINT_LINE) );
+			return dc.hitBreakpoint(debugConfig, getBreakpointLocation(FILE, BREAKPOINT_LINE));
 		});
 
 	});
@@ -542,8 +542,8 @@
 
 				dc.waitForEvent('initialized').then(() => {
 					return dc.setBreakpointsRequest({
-						lines: [ location.line ],
-						breakpoints: [ { line: location.line, condition: 'i == 2' } ],
+						lines: [location.line],
+						breakpoints: [{ line: location.line, condition: 'i == 2' }],
 						source: { path: location.path }
 					});
 				}).then(() => {
@@ -582,12 +582,12 @@
 			).then(() =>
 				// Add a condition to the breakpoint, and make sure it runs until 'i == 2'.
 				dc.setBreakpointsRequest({
-					lines: [ location.line ],
-					breakpoints: [ { line: location.line, condition: 'i == 2' } ],
+					lines: [location.line],
+					breakpoints: [{ line: location.line, condition: 'i == 2' }],
 					source: { path: location.path }
 				}).then(() =>
 					Promise.all([
-						dc.continueRequest({threadId: 1}),
+						dc.continueRequest({ threadId: 1 }),
 						dc.assertStoppedLocation('breakpoint', location)
 					]).then(() =>
 						// The program is stopped at the breakpoint, check to make sure 'i == 2'.
@@ -616,8 +616,8 @@
 
 				dc.waitForEvent('initialized').then(() => {
 					return dc.setBreakpointsRequest({
-						lines: [ location.line ],
-						breakpoints: [ { line: location.line, condition: 'i == 2' } ],
+						lines: [location.line],
+						breakpoints: [{ line: location.line, condition: 'i == 2' }],
 						source: { path: location.path }
 					});
 				}).then(() => {
@@ -634,12 +634,12 @@
 			).then(() =>
 				// Remove the breakpoint condition, and make sure the program runs until 'i == 3'.
 				dc.setBreakpointsRequest({
-					lines: [ location.line ],
-					breakpoints: [ { line: location.line } ],
+					lines: [location.line],
+					breakpoints: [{ line: location.line }],
 					source: { path: location.path }
 				}).then(() =>
 					Promise.all([
-						dc.continueRequest({threadId: 1}),
+						dc.continueRequest({ threadId: 1 }),
 						dc.assertStoppedLocation('breakpoint', location)
 					]).then(() =>
 						// The program is stopped at the breakpoint, check to make sure 'i == 3'.
@@ -669,7 +669,7 @@
 
 				dc.waitForEvent('initialized').then(() => {
 					return dc.setExceptionBreakpointsRequest({
-						filters: [ 'all' ]
+						filters: ['all']
 					});
 				}).then(() => {
 					return dc.configurationDoneRequest();
@@ -677,7 +677,7 @@
 
 				dc.launch(debugConfig),
 
-				dc.assertStoppedLocation('panic', {} )
+				dc.assertStoppedLocation('panic', {})
 			]);
 		});
 	});
diff --git a/test/integration/goDebugConfiguration.test.ts b/test/integration/goDebugConfiguration.test.ts
index 3d363fa..da17c3d 100644
--- a/test/integration/goDebugConfiguration.test.ts
+++ b/test/integration/goDebugConfiguration.test.ts
@@ -16,7 +16,7 @@
 		await updateGoVarsFromConfig();
 
 		// Set up the test fixtures.
-		const fixtureSourcePath = path.join(__dirname, '..', '..', '..', 'test', 'fixtures');
+		const fixtureSourcePath = path.join(__dirname, '..', '..', '..', 'test', 'testdata');
 		const filePath = path.join(fixtureSourcePath, 'baseTest', 'test.go');
 		await vscode.workspace.openTextDocument(vscode.Uri.file(filePath));
 	});
@@ -41,11 +41,11 @@
 
 	interface Input {
 		env?: { [key: string]: any };
-		envFile?: string|string[];
-		toolsEnv?: { [key: string]: any};
+		envFile?: string | string[];
+		toolsEnv?: { [key: string]: any };
 	}
 
-	function runTest(input: Input,	expected: { [key: string]: any}) {
+	function runTest(input: Input, expected: { [key: string]: any }) {
 		sandbox.stub(goEnv, 'toolExecutionEnvironment').returns(input.toolsEnv || {});
 		const config = debugConfigProvider.resolveDebugConfigurationWithSubstitutedVariables(undefined, {
 			type: 'go',
@@ -66,28 +66,31 @@
 	test('toolsEnvVars is propagated', () => {
 		const toolsEnv = {
 			GOPATH: '/gopath',
-			GOOS: 'valueFromToolsEnv'};
+			GOOS: 'valueFromToolsEnv'
+		};
 
-		runTest({toolsEnv}, {
+		runTest({ toolsEnv }, {
 			GOPATH: '/gopath',
-			GOOS: 'valueFromToolsEnv'});
+			GOOS: 'valueFromToolsEnv'
+		});
 	});
 
 	test('preserves settings from launchArgs.env', () => {
-		const env = {GOPATH: 'valueFromEnv', GOOS: 'valueFromEnv2'};
-		runTest({env}, {
+		const env = { GOPATH: 'valueFromEnv', GOOS: 'valueFromEnv2' };
+		runTest({ env }, {
 			GOPATH: 'valueFromEnv',
-			GOOS: 'valueFromEnv2'});
+			GOOS: 'valueFromEnv2'
+		});
 	});
 
 	test('preserves settings from launchArgs.envFile', () => {
 		const envFile = path.join(tmpDir, 'env');
 		fs.writeFileSync(envFile, 'GOPATH=valueFromEnvFile');
-		runTest({envFile}, {GOPATH: 'valueFromEnvFile'});
+		runTest({ envFile }, { GOPATH: 'valueFromEnvFile' });
 	});
 
 	test('launchArgs.env overwrites launchArgs.envFile', () => {
-		const env = {SOMEVAR1: 'valueFromEnv'};
+		const env = { SOMEVAR1: 'valueFromEnv' };
 		const envFile = path.join(tmpDir, 'env');
 		fs.writeFileSync(envFile, [
 			'SOMEVAR1=valueFromEnvFile1',
@@ -95,7 +98,8 @@
 
 		runTest({ env, envFile }, {
 			SOMEVAR1: 'valueFromEnv',
-			SOMEVAR2: 'valueFromEnvFile2'});
+			SOMEVAR2: 'valueFromEnvFile2'
+		});
 	});
 
 	test('launchArgs.env overwrites toolsEnvVar', () => {
@@ -105,11 +109,12 @@
 			SOMEVAR2: 'valueFromToolsEnvVar2'
 		};
 
-		const env = {SOMEVAR1: 'valueFromEnv'};
+		const env = { SOMEVAR1: 'valueFromEnv' };
 		runTest({ env, toolsEnv }, {
 			GOPATH: '/gopath',
 			SOMEVAR1: 'valueFromEnv',
-			SOMEVAR2: 'valueFromToolsEnvVar2'});
+			SOMEVAR2: 'valueFromToolsEnvVar2'
+		});
 	});
 
 	test('launchArgs.envFile overwrites toolsEnvVar', () => {
@@ -125,6 +130,7 @@
 		runTest({ toolsEnv, envFile }, {
 			GOPATH: '/gopath',
 			SOMEVAR1: 'valueFromToolsEnvVar1',
-			SOMEVAR2: 'valueFromEnvFile2'});
+			SOMEVAR2: 'valueFromEnvFile2'
+		});
 	});
 });
diff --git a/test/integration/statusbar.test.ts b/test/integration/statusbar.test.ts
index 153f36b..db3faa6 100644
--- a/test/integration/statusbar.test.ts
+++ b/test/integration/statusbar.test.ts
@@ -134,7 +134,7 @@
 		// build a fake go binary and place it in tmpRootBin.
 		fs.mkdirSync(tmpRootBin);
 
-		const fixtureSourcePath = path.join(__dirname, '..', '..', '..', 'test', 'fixtures', 'testhelpers');
+		const fixtureSourcePath = path.join(__dirname, '..', '..', '..', 'test', 'testdata', 'testhelpers');
 		const execFile = util.promisify(cp.execFile);
 		const goRuntimePath = ourutil.getBinPath('go');
 		const { stderr } = await execFile(
diff --git a/test/integration/test.test.ts b/test/integration/test.test.ts
index d7028dd..3350838 100644
--- a/test/integration/test.test.ts
+++ b/test/integration/test.test.ts
@@ -17,7 +17,7 @@
 suite('Test Go Test', function () {
 	this.timeout(10000);
 
-	const sourcePath = path.join(__dirname, '..', '..', '..', 'test', 'fixtures', 'goTestTest');
+	const sourcePath = path.join(__dirname, '..', '..', '..', 'test', 'testdata', 'goTestTest');
 
 	let tmpGopath: string;
 	let repoPath: string;
@@ -50,7 +50,7 @@
 	}
 
 	async function runTest(
-		input: { isMod: boolean, includeSubDirectories: boolean, testFlags?: string[], applyCodeCoverage?: boolean},
+		input: { isMod: boolean, includeSubDirectories: boolean, testFlags?: string[], applyCodeCoverage?: boolean },
 		wantFiles: string[]) {
 
 		fs.copySync(sourcePath, repoPath, { recursive: true });
@@ -114,8 +114,8 @@
 			{ isMod: true, includeSubDirectories: true, testFlags: ['-v'] },
 			[path.join(repoPath, 'a_test.go'), path.join(repoPath, 'b', 'b_test.go')]);
 		await runTest(
-				{ isMod: true, includeSubDirectories: true, testFlags: ['-race'], applyCodeCoverage: true },
-				[path.join(repoPath, 'a_test.go'), path.join(repoPath, 'b', 'b_test.go')]);
+			{ isMod: true, includeSubDirectories: true, testFlags: ['-race'], applyCodeCoverage: true },
+			[path.join(repoPath, 'a_test.go'), path.join(repoPath, 'b', 'b_test.go')]);
 		await runTest(
 			{ isMod: true, includeSubDirectories: false, testFlags: ['-v'] },
 			[path.join(repoPath, 'a_test.go')]);
diff --git a/test/runTest.ts b/test/runTest.ts
index edb587e..22dc780 100644
--- a/test/runTest.ts
+++ b/test/runTest.ts
@@ -2,8 +2,8 @@
 import { runTests } from 'vscode-test';
 
 async function main() {
-		// The folder containing the Extension Manifest package.json
-		// Passed to `--extensionDevelopmentPath`
+	// The folder containing the Extension Manifest package.json
+	// Passed to `--extensionDevelopmentPath`
 	const extensionDevelopmentPath = path.resolve(__dirname, '../../');
 
 	let failed = false;
@@ -30,9 +30,9 @@
 		// dynamically adding folders.
 		// tslint:disable-next-line:max-line-length
 		// https://github.com/microsoft/vscode/blob/890f62dfd9f3e70198931f788c5c332b3e8b7ad7/src/vs/workbench/services/workspaces/browser/abstractWorkspaceEditingService.ts#L281
 		// So, we start the test extension host with a dummy workspace (test/gopls/testfixtures/src/workspace)
 		// and copy necessary files to the workspace.
-		const ws = path.resolve(extensionDevelopmentPath, 'test/gopls/testfixtures/src/workspace');
+		const ws = path.resolve(extensionDevelopmentPath, 'test/gopls/testdata/src/workspace');
 
 		await runTests({
 			extensionDevelopmentPath,
@@ -30,9 +30,9 @@
 		// tslint:disable-next-line:max-line-length
 		// https://github.com/microsoft/vscode/blob/890f62dfd9f3e70198931f788c5c332b3e8b7ad7/src/vs/workbench/services/workspaces/browser/abstractWorkspaceEditingService.ts#L281
-		// So, we start the test extension host with a dummy workspace (test/gopls/testfixtures/src/workspace)
+		// So, we start the test extension host with a dummy workspace (test/gopls/testdata/src/workspace)
 		// and copy necessary files to the workspace.
diff --git a/test/fixtures/baseTest/go.mod b/test/testdata/baseTest/go.mod
similarity index 100%
rename from test/fixtures/baseTest/go.mod
rename to test/testdata/baseTest/go.mod
diff --git a/test/fixtures/baseTest/sample_test.go b/test/testdata/baseTest/sample_test.go
similarity index 100%
rename from test/fixtures/baseTest/sample_test.go
rename to test/testdata/baseTest/sample_test.go
diff --git a/test/fixtures/baseTest/test.go b/test/testdata/baseTest/test.go
similarity index 100%
rename from test/fixtures/baseTest/test.go
rename to test/testdata/baseTest/test.go
diff --git a/test/fixtures/buildTags/go.mod b/test/testdata/buildTags/go.mod
similarity index 100%
rename from test/fixtures/buildTags/go.mod
rename to test/testdata/buildTags/go.mod
diff --git a/test/fixtures/buildTags/hello.go b/test/testdata/buildTags/hello.go
similarity index 100%
rename from test/fixtures/buildTags/hello.go
rename to test/testdata/buildTags/hello.go
diff --git a/test/fixtures/codelens/codelens_benchmark_test.go b/test/testdata/codelens/codelens_benchmark_test.go
similarity index 100%
rename from test/fixtures/codelens/codelens_benchmark_test.go
rename to test/testdata/codelens/codelens_benchmark_test.go
diff --git a/test/fixtures/codelens/codelens_test.go b/test/testdata/codelens/codelens_test.go
similarity index 100%
rename from test/fixtures/codelens/codelens_test.go
rename to test/testdata/codelens/codelens_test.go
diff --git a/test/fixtures/codelens/go.mod b/test/testdata/codelens/go.mod
similarity index 100%
rename from test/fixtures/codelens/go.mod
rename to test/testdata/codelens/go.mod
diff --git a/test/fixtures/completions/exportedMemberDocs.go b/test/testdata/completions/exportedMemberDocs.go
similarity index 100%
rename from test/fixtures/completions/exportedMemberDocs.go
rename to test/testdata/completions/exportedMemberDocs.go
diff --git a/test/fixtures/completions/go.mod b/test/testdata/completions/go.mod
similarity index 100%
rename from test/fixtures/completions/go.mod
rename to test/testdata/completions/go.mod
diff --git a/test/fixtures/completions/nosnippets.go b/test/testdata/completions/nosnippets.go
similarity index 100%
rename from test/fixtures/completions/nosnippets.go
rename to test/testdata/completions/nosnippets.go
diff --git a/test/fixtures/completions/snippets.go b/test/testdata/completions/snippets.go
similarity index 100%
rename from test/fixtures/completions/snippets.go
rename to test/testdata/completions/snippets.go
diff --git a/test/fixtures/completions/unimportedMultiplePkgs.go b/test/testdata/completions/unimportedMultiplePkgs.go
similarity index 100%
rename from test/fixtures/completions/unimportedMultiplePkgs.go
rename to test/testdata/completions/unimportedMultiplePkgs.go
diff --git a/test/fixtures/completions/unimportedPkgs.go b/test/testdata/completions/unimportedPkgs.go
similarity index 100%
rename from test/fixtures/completions/unimportedPkgs.go
rename to test/testdata/completions/unimportedPkgs.go
diff --git a/test/fixtures/condbp/condbp.go b/test/testdata/condbp/condbp.go
similarity index 100%
rename from test/fixtures/condbp/condbp.go
rename to test/testdata/condbp/condbp.go
diff --git a/test/fixtures/condbp/go.mod b/test/testdata/condbp/go.mod
similarity index 100%
rename from test/fixtures/condbp/go.mod
rename to test/testdata/condbp/go.mod
diff --git a/test/fixtures/coverage/a/a.go b/test/testdata/coverage/a/a.go
similarity index 100%
rename from test/fixtures/coverage/a/a.go
rename to test/testdata/coverage/a/a.go
diff --git a/test/fixtures/coverage/b/b.go b/test/testdata/coverage/b/b.go
similarity index 100%
rename from test/fixtures/coverage/b/b.go
rename to test/testdata/coverage/b/b.go
diff --git a/test/fixtures/coverage/cover.out b/test/testdata/coverage/cover.out
similarity index 100%
rename from test/fixtures/coverage/cover.out
rename to test/testdata/coverage/cover.out
diff --git a/test/fixtures/coverage/go.mod b/test/testdata/coverage/go.mod
similarity index 100%
rename from test/fixtures/coverage/go.mod
rename to test/testdata/coverage/go.mod
diff --git a/test/fixtures/diffTestData/file1.go b/test/testdata/diffTestData/file1.go
similarity index 100%
rename from test/fixtures/diffTestData/file1.go
rename to test/testdata/diffTestData/file1.go
diff --git a/test/fixtures/diffTestData/file2.go b/test/testdata/diffTestData/file2.go
similarity index 100%
rename from test/fixtures/diffTestData/file2.go
rename to test/testdata/diffTestData/file2.go
diff --git a/test/fixtures/diffTestData/go.mod b/test/testdata/diffTestData/go.mod
similarity index 100%
rename from test/fixtures/diffTestData/go.mod
rename to test/testdata/diffTestData/go.mod
diff --git a/test/fixtures/errorsTest/errors.go b/test/testdata/errorsTest/errors.go
similarity index 100%
rename from test/fixtures/errorsTest/errors.go
rename to test/testdata/errorsTest/errors.go
diff --git a/test/fixtures/errorsTest/go.mod b/test/testdata/errorsTest/go.mod
similarity index 100%
rename from test/fixtures/errorsTest/go.mod
rename to test/testdata/errorsTest/go.mod
diff --git a/test/fixtures/fillStruct/go.mod b/test/testdata/fillStruct/go.mod
similarity index 100%
rename from test/fixtures/fillStruct/go.mod
rename to test/testdata/fillStruct/go.mod
diff --git a/test/fixtures/fillStruct/golden_1.go b/test/testdata/fillStruct/golden_1.go
similarity index 100%
rename from test/fixtures/fillStruct/golden_1.go
rename to test/testdata/fillStruct/golden_1.go
diff --git a/test/fixtures/fillStruct/golden_2.go b/test/testdata/fillStruct/golden_2.go
similarity index 100%
rename from test/fixtures/fillStruct/golden_2.go
rename to test/testdata/fillStruct/golden_2.go
diff --git a/test/fixtures/fillStruct/input_1.go b/test/testdata/fillStruct/input_1.go
similarity index 100%
rename from test/fixtures/fillStruct/input_1.go
rename to test/testdata/fillStruct/input_1.go
diff --git a/test/fixtures/fillStruct/input_2.go b/test/testdata/fillStruct/input_2.go
similarity index 100%
rename from test/fixtures/fillStruct/input_2.go
rename to test/testdata/fillStruct/input_2.go
diff --git a/test/fixtures/generatetests/generatetests.go b/test/testdata/generatetests/generatetests.go
similarity index 100%
rename from test/fixtures/generatetests/generatetests.go
rename to test/testdata/generatetests/generatetests.go
diff --git a/test/fixtures/generatetests/go.mod b/test/testdata/generatetests/go.mod
similarity index 100%
rename from test/fixtures/generatetests/go.mod
rename to test/testdata/generatetests/go.mod
diff --git a/test/fixtures/goTestTest/a_test.go b/test/testdata/goTestTest/a_test.go
similarity index 100%
rename from test/fixtures/goTestTest/a_test.go
rename to test/testdata/goTestTest/a_test.go
diff --git a/test/fixtures/goTestTest/b/b_test.go b/test/testdata/goTestTest/b/b_test.go
similarity index 100%
rename from test/fixtures/goTestTest/b/b_test.go
rename to test/testdata/goTestTest/b/b_test.go
diff --git a/test/fixtures/goTestTest/go.mod b/test/testdata/goTestTest/go.mod
similarity index 100%
rename from test/fixtures/goTestTest/go.mod
rename to test/testdata/goTestTest/go.mod
diff --git a/test/fixtures/gogetdocTestData/go.mod b/test/testdata/gogetdocTestData/go.mod
similarity index 100%
rename from test/fixtures/gogetdocTestData/go.mod
rename to test/testdata/gogetdocTestData/go.mod
diff --git a/test/fixtures/gogetdocTestData/test.go b/test/testdata/gogetdocTestData/test.go
similarity index 100%
rename from test/fixtures/gogetdocTestData/test.go
rename to test/testdata/gogetdocTestData/test.go
diff --git a/test/fixtures/importTest/cgoImports.go b/test/testdata/importTest/cgoImports.go
similarity index 100%
rename from test/fixtures/importTest/cgoImports.go
rename to test/testdata/importTest/cgoImports.go
diff --git a/test/fixtures/importTest/go.mod b/test/testdata/importTest/go.mod
similarity index 100%
rename from test/fixtures/importTest/go.mod
rename to test/testdata/importTest/go.mod
diff --git a/test/fixtures/importTest/groupImports.go b/test/testdata/importTest/groupImports.go
similarity index 100%
rename from test/fixtures/importTest/groupImports.go
rename to test/testdata/importTest/groupImports.go
diff --git a/test/fixtures/importTest/noimports.go b/test/testdata/importTest/noimports.go
similarity index 100%
rename from test/fixtures/importTest/noimports.go
rename to test/testdata/importTest/noimports.go
diff --git a/test/fixtures/importTest/singleImports.go b/test/testdata/importTest/singleImports.go
similarity index 100%
rename from test/fixtures/importTest/singleImports.go
rename to test/testdata/importTest/singleImports.go
diff --git a/test/fixtures/linterTest/go.mod b/test/testdata/linterTest/go.mod
similarity index 100%
rename from test/fixtures/linterTest/go.mod
rename to test/testdata/linterTest/go.mod
diff --git a/test/fixtures/linterTest/linter_1.go b/test/testdata/linterTest/linter_1.go
similarity index 100%
rename from test/fixtures/linterTest/linter_1.go
rename to test/testdata/linterTest/linter_1.go
diff --git a/test/fixtures/linterTest/linter_2.go b/test/testdata/linterTest/linter_2.go
similarity index 100%
rename from test/fixtures/linterTest/linter_2.go
rename to test/testdata/linterTest/linter_2.go
diff --git a/test/fixtures/outlineTest/go.mod b/test/testdata/outlineTest/go.mod
similarity index 100%
rename from test/fixtures/outlineTest/go.mod
rename to test/testdata/outlineTest/go.mod
diff --git a/test/fixtures/outlineTest/test.go b/test/testdata/outlineTest/test.go
similarity index 100%
rename from test/fixtures/outlineTest/test.go
rename to test/testdata/outlineTest/test.go
diff --git a/test/fixtures/panic/go.mod b/test/testdata/panic/go.mod
similarity index 100%
rename from test/fixtures/panic/go.mod
rename to test/testdata/panic/go.mod
diff --git a/test/fixtures/panic/panic.go b/test/testdata/panic/panic.go
similarity index 100%
rename from test/fixtures/panic/panic.go
rename to test/testdata/panic/panic.go
diff --git a/test/fixtures/testTags/go.mod b/test/testdata/testTags/go.mod
similarity index 100%
rename from test/fixtures/testTags/go.mod
rename to test/testdata/testTags/go.mod
diff --git a/test/fixtures/testTags/hello_test.go b/test/testdata/testTags/hello_test.go
similarity index 100%
rename from test/fixtures/testTags/hello_test.go
rename to test/testdata/testTags/hello_test.go
diff --git a/test/fixtures/testhelpers/fakego.go b/test/testdata/testhelpers/fakego.go
similarity index 100%
rename from test/fixtures/testhelpers/fakego.go
rename to test/testdata/testhelpers/fakego.go
diff --git a/test/fixtures/vendoring/main.go b/test/testdata/vendoring/main.go
similarity index 100%
rename from test/fixtures/vendoring/main.go
rename to test/testdata/vendoring/main.go
diff --git a/test/fixtures/vendoring/vendor/example.com/vendorpls/lib.go b/test/testdata/vendoring/vendor/example.com/vendorpls/lib.go
similarity index 100%
rename from test/fixtures/vendoring/vendor/example.com/vendorpls/lib.go
rename to test/testdata/vendoring/vendor/example.com/vendorpls/lib.go